@@ -24,6 +24,10 @@ int main(int argc, char *argv[])
 {
     QApplication a(argc, argv);
     MagRead w;
+    a.setApplicationName( "MagRead" );
+    a.setApplicationVersion( QUOTE( APP_VERSION ) );
+    a.setOrganizationDomain( "tehinterweb.com" );
+    a.setOrganizationName( "lint" );
 #if defined(Q_WS_S60)
     w.showMaximized();
 #else
